aboutsummaryrefslogtreecommitdiff
path: root/plugin-api.h
diff options
context:
space:
mode:
authorPřemysl Janouch <p.janouch@gmail.com>2015-05-13 06:57:06 +0200
committerPřemysl Janouch <p.janouch@gmail.com>2015-05-13 06:57:06 +0200
commitde4009fb4de679b2efe89e2736436060eb4a8e6d (patch)
tree295e3f632b2f9efdd858904b851602c5d77ef96e /plugin-api.h
parentb2cc2709c6fcf8d3fdc123e6d926be2d02c1221f (diff)
downloadponymap-de4009fb4de679b2efe89e2736436060eb4a8e6d.tar.gz
ponymap-de4009fb4de679b2efe89e2736436060eb4a8e6d.tar.xz
ponymap-de4009fb4de679b2efe89e2736436060eb4a8e6d.zip
Aborting units -> stopping units
Diffstat (limited to 'plugin-api.h')
-rw-r--r--plugin-api.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugin-api.h b/plugin-api.h
index 740967f..3431e3c 100644
--- a/plugin-api.h
+++ b/plugin-api.h
@@ -39,7 +39,7 @@ struct service
int flags; ///< Service flags
void *user_data; ///< User data
- // scan_init -> on_data* -> [on_eof/on_error] -> on_aborted -> scan_free
+ // scan_init -> on_data* -> [on_eof/on_error] -> on_stopped -> scan_free
/// Initialize a scan, returning a handle to it
void *(*scan_init) (struct service *self, struct unit *u);
@@ -58,8 +58,8 @@ struct service
/// Network or other error has occured
void (*on_error) (void *handle);
- /// The scan has been aborted
- void (*on_aborted) (void *handle);
+ /// The scan has been stopped
+ void (*on_stopped) (void *handle);
};
struct plugin_api
@@ -83,7 +83,7 @@ struct plugin_api
void (*unit_add_info) (struct unit *u, const char *result);
/// Abort the scan, close the connection
- void (*unit_abort) (struct unit *u);
+ void (*unit_stop) (struct unit *u);
};
struct plugin_info